@@ -19,15 +19,14 @@ function(Marker,
            if (is.numeric(position)) {
           pixelOffset=paste('new google.maps.Size',pixelOffset[1],',',pixelOffset[1],')')
           }
-x=paste( ' var infowindow = new google.maps.InfoWindow({ content: "",
-                                                        position:',position,
-                                                       ', disableAutoPan:', disableAutoPan,
+x=paste( ' var infowindow = new google.maps.InfoWindow({ content: "", disableAutoPan:', disableAutoPan,
                                                         ', maxWidth :',maxWidth,
                                                         ', pixelOffset :',pixelOffset,
                                                         '  }); ',
          '\n google.maps.event.addListener(',Marker,
-',"',event,'",function(event){ \n infowindow.content="',content,'" ; 
-infowindow.position=',position ,';
+',"',event,'",function(event){ 
+\n infowindow.setContent("',content,'"); 
+\n infowindow.setPosition(event.latLng);
 infowindow.open(',map,',' ,Marker,')}); ',sep="")
 
 return(x)
